==> galileo-1.0.0.tar.gz: galileo-1.0.0/src/galileo/resources/api/trace/log_traces_projects_project_id_traces_post.py <==
from http import HTTPStatus
from typing import Any, Optional, Union

import httpx

from ... import errors
from ...client import AuthenticatedClient, Client
from ...models.http_validation_error import HTTPValidationError
from ...models.log_records_ingest_request import LogRecordsIngestRequest
from ...models.log_records_ingest_response import LogRecordsIngestResponse
from ...types import Response


def _get_kwargs(project_id: str, *, body: LogRecordsIngestRequest) -> dict[str, Any]:
    headers: dict[str, Any] = {}

    _kwargs: dict[str, Any] = {"method": "post", "url": f"/projects/{project_id}/traces"}

    _body = body.to_dict()

    _kwargs["json"] = _body
    headers["Content-Type"] = "application/json"

    _kwargs["headers"] = headers
    return _kwargs


def _parse_response(
    *, client: Union[AuthenticatedClient, Client], response: httpx.Response
) -> Optional[Union[HTTPValidationError, LogRecordsIngestResponse]]:
    if response.status_code == 200:
        response_200 = LogRecordsIngestResponse.from_dict(response.json())

        return response_200
    if response.status_code == 422:
        response_422 = HTTPValidationError.from_dict(response.json())

        return response_422
    if client.raise_on_unexpected_status:
        raise errors.UnexpectedStatus(response.status_code, response.content)
    else:
        return None


def _build_response(
    *, client: Union[AuthenticatedClient, Client], response: httpx.Response
) -> Response[Union[HTTPValidationError, LogRecordsIngestResponse]]:
    return Response(
        status_code=HTTPStatus(response.status_code),
        content=response.content,
        headers=response.headers,
        parsed=_parse_response(client=client, response=response),
    )


def sync_detailed(
    project_id: str, *, client: AuthenticatedClient, body: LogRecordsIngestRequest
) -> Response[Union[HTTPValidationError, LogRecordsIngestResponse]]:
    """Log Traces

    Args:
        project_id (str):
        body (LogRecordsIngestRequest):

    Raises:
        errors.UnexpectedStatus: If the server returns an undocumented status code and Client.raise_on_unexpected_status is True.
        httpx.TimeoutException: If the request takes longer than Client.timeout.

    Returns:
        Response[Union[HTTPValidationError, LogRecordsIngestResponse]]
    """

    kwargs = _get_kwargs(project_id=project_id, body=body)

    response = client.get_httpx_client().request(**kwargs)

    return _build_response(client=client, response=response)


def sync(
    project_id: str, *, client: AuthenticatedClient, body: LogRecordsIngestRequest
) -> Optional[Union[HTTPValidationError, LogRecordsIngestResponse]]:
    """Log Traces

    Args:
        project_id (str):
        body (LogRecordsIngestRequest):

    Raises:
        errors.UnexpectedStatus: If the server returns an undocumented status code and Client.raise_on_unexpected_status is True.
        httpx.TimeoutException: If the request takes longer than Client.timeout.

    Returns:
        Union[HTTPValidationError, LogRecordsIngestResponse]
    """

    return sync_detailed(project_id=project_id, client=client, body=body).parsed


async def asyncio_detailed(
    project_id: str, *, client: AuthenticatedClient, body: LogRecordsIngestRequest
) -> Response[Union[HTTPValidationError, LogRecordsIngestResponse]]:
    """Log Traces

    Args:
        project_id (str):
        body (LogRecordsIngestRequest):

    Raises:
        errors.UnexpectedStatus: If the server returns an undocumented status code and Client.raise_on_unexpected_status is True.
        httpx.TimeoutException: If the request takes longer than Client.timeout.

    Returns:
        Response[Union[HTTPValidationError, LogRecordsIngestResponse]]
    """

    kwargs = _get_kwargs(project_id=project_id, body=body)

    response = await client.get_async_httpx_client().request(**kwargs)

    return _build_response(client=client, response=response)


async def asyncio(
    project_id: str, *, client: AuthenticatedClient, body: LogRecordsIngestRequest
) -> Optional[Union[HTTPValidationError, LogRecordsIngestResponse]]:
    """Log Traces

    Args:
        project_id (str):
        body (LogRecordsIngestRequest):

    Raises:
        errors.UnexpectedStatus: If the server returns an undocumented status code and Client.raise_on_unexpected_status is True.
        httpx.TimeoutException: If the request takes longer than Client.timeout.

    Returns:
        Union[HTTPValidationError, LogRecordsIngestResponse]
    """

    return (await asyncio_detailed(project_id=project_id, client=client, body=body)).parsed

==> galileo-1.8.1.tar.gz: galileo-1.8.1/src/galileo/resources/api/trace/log_traces_projects_project_id_traces_post.py <==
from http import HTTPStatus
from typing import Any, Optional, Union

import httpx

from ... import errors
from ...client import AuthenticatedClient, Client
from ...models.http_validation_error import HTTPValidationError
from ...models.log_traces_ingest_request import LogTracesIngestRequest
from ...models.log_traces_ingest_response import LogTracesIngestResponse
from ...types import Response


def _get_kwargs(project_id: str, *, body: LogTracesIngestRequest) -> dict[str, Any]:
    headers: dict[str, Any] = {}

    _kwargs: dict[str, Any] = {"method": "post", "url": f"/projects/{project_id}/traces"}

    _kwargs["json"] = body.to_dict()

    headers["Content-Type"] = "application/json"

    _kwargs["headers"] = headers
    return _kwargs


def _parse_response(
    *, client: Union[AuthenticatedClient, Client], response: httpx.Response
) -> Optional[Union[HTTPValidationError, LogTracesIngestResponse]]:
    if response.status_code == 200:
        response_200 = LogTracesIngestResponse.from_dict(response.json())

        return response_200
    if response.status_code == 422:
        response_422 = HTTPValidationError.from_dict(response.json())

        return response_422
    if client.raise_on_unexpected_status:
        raise errors.UnexpectedStatus(response.status_code, response.content)
    else:
        return None


def _build_response(
    *, client: Union[AuthenticatedClient, Client], response: httpx.Response
) -> Response[Union[HTTPValidationError, LogTracesIngestResponse]]:
    return Response(
        status_code=HTTPStatus(response.status_code),
        content=response.content,
        headers=response.headers,
        parsed=_parse_response(client=client, response=response),
    )


def sync_detailed(
    project_id: str, *, client: AuthenticatedClient, body: LogTracesIngestRequest
) -> Response[Union[HTTPValidationError, LogTracesIngestResponse]]:
    """Log Traces

    Args:
        project_id (str):
        body (LogTracesIngestRequest): Request model for ingesting traces.

    Raises:
        errors.UnexpectedStatus: If the server returns an undocumented status code and Client.raise_on_unexpected_status is True.
        httpx.TimeoutException: If the request takes longer than Client.timeout.

    Returns:
        Response[Union[HTTPValidationError, LogTracesIngestResponse]]
    """

    kwargs = _get_kwargs(project_id=project_id, body=body)

    response = client.get_httpx_client().request(**kwargs)

    return _build_response(client=client, response=response)


def sync(
    project_id: str, *, client: AuthenticatedClient, body: LogTracesIngestRequest
) -> Optional[Union[HTTPValidationError, LogTracesIngestResponse]]:
    """Log Traces

    Args:
        project_id (str):
        body (LogTracesIngestRequest): Request model for ingesting traces.

    Raises:
        errors.UnexpectedStatus: If the server returns an undocumented status code and Client.raise_on_unexpected_status is True.
        httpx.TimeoutException: If the request takes longer than Client.timeout.

    Returns:
        Union[HTTPValidationError, LogTracesIngestResponse]
    """

    return sync_detailed(project_id=project_id, client=client, body=body).parsed


async def asyncio_detailed(
    project_id: str, *, client: AuthenticatedClient, body: LogTracesIngestRequest
) -> Response[Union[HTTPValidationError, LogTracesIngestResponse]]:
    """Log Traces

    Args:
        project_id (str):
        body (LogTracesIngestRequest): Request model for ingesting traces.

    Raises:
        errors.UnexpectedStatus: If the server returns an undocumented status code and Client.raise_on_unexpected_status is True.
        httpx.TimeoutException: If the request takes longer than Client.timeout.

    Returns:
        Response[Union[HTTPValidationError, LogTracesIngestResponse]]
    """

    kwargs = _get_kwargs(project_id=project_id, body=body)

    response = await client.get_async_httpx_client().request(**kwargs)

    return _build_response(client=client, response=response)


async def asyncio(
    project_id: str, *, client: AuthenticatedClient, body: LogTracesIngestRequest
) -> Optional[Union[HTTPValidationError, LogTracesIngestResponse]]:
    """Log Traces

    Args:
        project_id (str):
        body (LogTracesIngestRequest): Request model for ingesting traces.

    Raises:
        errors.UnexpectedStatus: If the server returns an undocumented status code and Client.raise_on_unexpected_status is True.
        httpx.TimeoutException: If the request takes longer than Client.timeout.

    Returns:
        Union[HTTPValidationError, LogTracesIngestResponse]
    """

    return (await asyncio_detailed(project_id=project_id, client=client, body=body)).parsed
